==> ipplan-4.0.4.tbz: share/ipplan/admin/deletebounds.php <==
<?php

// IPplan v4.04
// Aug 24, 2001
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

require_once("../ipplanlib.php");
require_once("../adodb/adodb.inc.php");
require_once("../class.dbflib.php");
require_once("../layout/class.layout");
require_once("../auth.php");

$auth = new BasicAuthenticator(ADMINREALM, REALMERROR);

$auth->addUser(ADMINUSER, ADMINPASSWD);

// And now perform the authentication
$auth->authenticate();

// set language
myLanguage($HTTP_COOKIE_VARS['ipplanLanguage']);

setdefault("window",array("bgcolor"=>"white"));

$title=my_("Delete authority boundary results");
newhtml($w);

insert($w, wheader($title));
myheading($w, $title, "admin.php");

// explicitly cast variables as security measure against SQL injection
$boundsaddr=floor($boundsaddr);
if (!$HTTP_GET_VARS) {
   myError($w, my_("You cannot reload or bookmark this page!"));
}

// basic sequence is connect, search, interpret search
// result, close connection

$ds=new IPplanDbf() or myError($w, my_("Could not connect to database"));

$ds->DbfTransactionStart();
$result=&$ds->ds->Execute("DELETE FROM bounds
                        WHERE grp=".$ds->ds->qstr($grp)." AND boundsaddr=$boundsaddr");
  
if ($result) {
   $ds->DbfTransactionEnd();
   insert($w,text(my_("Boundary deleted")));
}
else {
   insert($w,text(my_("Boundary could not be deleted")));
}

printhtml($w);

?>

==> ipplan-4.80b.tbz: share/ipplan/admin/deletebounds.php <==
<?php

// IPplan v4.80
// Aug 24, 2001
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

require_once("../ipplanlib.php");
require_once("../adodb/adodb.inc.php");
require_once("../class.dbflib.php");
require_once("../layout/class.layout");
require_once("../auth.php");

$auth = new BasicAuthenticator(ADMINREALM, REALMERROR);

$auth->addUser(ADMINUSER, ADMINPASSWD);

// And now perform the authentication
$auth->authenticate();

// set language
isset($_COOKIE["ipplanLanguage"]) && myLanguage($_COOKIE['ipplanLanguage']);

//setdefault("window",array("bgcolor"=>"white"));

$title=my_("Delete authority boundary results");
newhtml($p);
$w=myheading($p, $title);

// explicitly cast variables as security measure against SQL injection
list($boundsaddr, $grp) = myRegister("B:boundsaddr S:grp");

if (!$_GET) {
   myError($w,$p, my_("You cannot reload or bookmark this page!"));
}

// basic sequence is connect, search, interpret search
// result, close connection

$ds=new IPplanDbf() or myError($w,$p, my_("Could not connect to database"));

$ds->DbfTransactionStart();
$result=&$ds->ds->Execute("DELETE FROM bounds
                        WHERE grp=".$ds->ds->qstr($grp)." AND boundsaddr=$boundsaddr");
  
if ($result) {
   $ds->DbfTransactionEnd();
   insert($w,text(my_("Boundary deleted")));
}
else {
   insert($w,text(my_("Boundary could not be deleted")));
}

printhtml($p);

?>
